aboutsummaryrefslogtreecommitdiffstats
path: root/swarm/storage
diff options
context:
space:
mode:
authorWei-Ning Huang <w@byzantine-lab.io>2019-06-12 17:31:08 +0800
committerWei-Ning Huang <w@byzantine-lab.io>2019-09-17 16:57:29 +0800
commitac088de6322fc16ebe75c2e5554be73754bf1fe2 (patch)
tree086b7827d46a4d07b834cd94be73beaabb77b734 /swarm/storage
parent67d565f3f0e398e99bef96827f729e3e4b0edf31 (diff)
downloadgo-tangerine-ac088de6322fc16ebe75c2e5554be73754bf1fe2.tar
go-tangerine-ac088de6322fc16ebe75c2e5554be73754bf1fe2.tar.gz
go-tangerine-ac088de6322fc16ebe75c2e5554be73754bf1fe2.tar.bz2
go-tangerine-ac088de6322fc16ebe75c2e5554be73754bf1fe2.tar.lz
go-tangerine-ac088de6322fc16ebe75c2e5554be73754bf1fe2.tar.xz
go-tangerine-ac088de6322fc16ebe75c2e5554be73754bf1fe2.tar.zst
go-tangerine-ac088de6322fc16ebe75c2e5554be73754bf1fe2.zip
Rebrand as tangerine-network/go-tangerine
Diffstat (limited to 'swarm/storage')
-rw-r--r--swarm/storage/chunker.go8
-rw-r--r--swarm/storage/chunker_test.go2
-rw-r--r--swarm/storage/common_test.go4
-rw-r--r--swarm/storage/database.go2
-rw-r--r--swarm/storage/encryption/encryption_test.go6
-rw-r--r--swarm/storage/feed/binaryserializer.go2
-rw-r--r--swarm/storage/feed/binaryserializer_test.go2
-rw-r--r--swarm/storage/feed/cacheentry.go2
-rw-r--r--swarm/storage/feed/feed.go6
-rw-r--r--swarm/storage/feed/handler.go6
-rw-r--r--swarm/storage/feed/handler_test.go10
-rw-r--r--swarm/storage/feed/id.go6
-rw-r--r--swarm/storage/feed/id_test.go2
-rw-r--r--swarm/storage/feed/lookup/epoch_test.go2
-rw-r--r--swarm/storage/feed/lookup/lookup_test.go4
-rw-r--r--swarm/storage/feed/query.go4
-rw-r--r--swarm/storage/feed/request.go8
-rw-r--r--swarm/storage/feed/request_test.go6
-rw-r--r--swarm/storage/feed/sign.go4
-rw-r--r--swarm/storage/feed/testutil.go4
-rw-r--r--swarm/storage/feed/topic.go6
-rw-r--r--swarm/storage/feed/topic_test.go2
-rw-r--r--swarm/storage/feed/update.go2
-rw-r--r--swarm/storage/filestore_test.go2
-rw-r--r--swarm/storage/hasherstore.go4
-rw-r--r--swarm/storage/hasherstore_test.go4
-rw-r--r--swarm/storage/ldbstore.go8
-rw-r--r--swarm/storage/ldbstore_test.go8
-rw-r--r--swarm/storage/localstore.go6
-rw-r--r--swarm/storage/localstore/gc.go4
-rw-r--r--swarm/storage/localstore/gc_test.go2
-rw-r--r--swarm/storage/localstore/index_test.go2
-rw-r--r--swarm/storage/localstore/localstore.go8
-rw-r--r--swarm/storage/localstore/localstore_test.go10
-rw-r--r--swarm/storage/localstore/mode_get.go6
-rw-r--r--swarm/storage/localstore/mode_put.go4
-rw-r--r--swarm/storage/localstore/mode_put_test.go6
-rw-r--r--swarm/storage/localstore/mode_set.go2
-rw-r--r--swarm/storage/localstore/retrieval_index_test.go10
-rw-r--r--swarm/storage/localstore/subscription_pull.go6
-rw-r--r--swarm/storage/localstore/subscription_pull_test.go2
-rw-r--r--swarm/storage/localstore/subscription_push.go6
-rw-r--r--swarm/storage/localstore/subscription_push_test.go2
-rw-r--r--swarm/storage/localstore_test.go2
-rw-r--r--swarm/storage/memstore_test.go2
-rw-r--r--swarm/storage/mock/db/db.go4
-rw-r--r--swarm/storage/mock/db/db_test.go2
-rw-r--r--swarm/storage/mock/mem/mem.go4
-rw-r--r--swarm/storage/mock/mem/mem_test.go2
-rw-r--r--swarm/storage/mock/mock.go2
-rw-r--r--swarm/storage/mock/rpc/rpc.go8
-rw-r--r--swarm/storage/mock/rpc/rpc_test.go6
-rw-r--r--swarm/storage/mock/test/test.go6
-rw-r--r--swarm/storage/netstore.go4
-rw-r--r--swarm/storage/netstore_test.go6
-rw-r--r--swarm/storage/pyramid.go4
-rw-r--r--swarm/storage/types.go6
57 files changed, 130 insertions, 130 deletions
diff --git a/swarm/storage/chunker.go b/swarm/storage/chunker.go
index 7baed1849..873b8b5aa 100644
--- a/swarm/storage/chunker.go
+++ b/swarm/storage/chunker.go
@@ -24,12 +24,12 @@ import (
"sync"
"time"
- "github.com/dexon-foundation/dexon/metrics"
- ch "github.com/dexon-foundation/dexon/swarm/chunk"
- "github.com/dexon-foundation/dexon/swarm/log"
- "github.com/dexon-foundation/dexon/swarm/spancontext"
opentracing "github.com/opentracing/opentracing-go"
olog "github.com/opentracing/opentracing-go/log"
+ "github.com/tangerine-network/go-tangerine/metrics"
+ ch "github.com/tangerine-network/go-tangerine/swarm/chunk"
+ "github.com/tangerine-network/go-tangerine/swarm/log"
+ "github.com/tangerine-network/go-tangerine/swarm/spancontext"
)
/*
diff --git a/swarm/storage/chunker_test.go b/swarm/storage/chunker_test.go
index 90594d8c1..fc22db001 100644
--- a/swarm/storage/chunker_test.go
+++ b/swarm/storage/chunker_test.go
@@ -24,7 +24,7 @@ import (
"io"
"testing"
- "github.com/dexon-foundation/dexon/swarm/testutil"
+ "github.com/tangerine-network/go-tangerine/swarm/testutil"
"golang.org/x/crypto/sha3"
)
diff --git a/swarm/storage/common_test.go b/swarm/storage/common_test.go
index a5da906cc..cb00810b4 100644
--- a/swarm/storage/common_test.go
+++ b/swarm/storage/common_test.go
@@ -28,9 +28,9 @@ import (
"testing"
"time"
- "github.com/dexon-foundation/dexon/log"
- ch "github.com/dexon-foundation/dexon/swarm/chunk"
"github.com/mattn/go-colorable"
+ "github.com/tangerine-network/go-tangerine/log"
+ ch "github.com/tangerine-network/go-tangerine/swarm/chunk"
)
var (
diff --git a/swarm/storage/database.go b/swarm/storage/database.go
index 81aa37381..ec918c63f 100644
--- a/swarm/storage/database.go
+++ b/swarm/storage/database.go
@@ -20,10 +20,10 @@ package storage
// no need for queueing/caching
import (
- "github.com/dexon-foundation/dexon/metrics"
"github.com/syndtr/goleveldb/leveldb"
"github.com/syndtr/goleveldb/leveldb/iterator"
"github.com/syndtr/goleveldb/leveldb/opt"
+ "github.com/tangerine-network/go-tangerine/metrics"
)
const openFileLimit = 128
diff --git a/swarm/storage/encryption/encryption_test.go b/swarm/storage/encryption/encryption_test.go
index 42ecac870..69bea2d2a 100644
--- a/swarm/storage/encryption/encryption_test.go
+++ b/swarm/storage/encryption/encryption_test.go
@@ -20,9 +20,9 @@ import (
"bytes"
"testing"
- "github.com/dexon-foundation/dexon/common"
- "github.com/dexon-foundation/dexon/common/hexutil"
- "github.com/dexon-foundation/dexon/swarm/testutil"
+ "github.com/tangerine-network/go-tangerine/common"
+ "github.com/tangerine-network/go-tangerine/common/hexutil"
+ "github.com/tangerine-network/go-tangerine/swarm/testutil"
"golang.org/x/crypto/sha3"
)
diff --git a/swarm/storage/feed/binaryserializer.go b/swarm/storage/feed/binaryserializer.go
index d6a065553..6d5d274ab 100644
--- a/swarm/storage/feed/binaryserializer.go
+++ b/swarm/storage/feed/binaryserializer.go
@@ -16,7 +16,7 @@
package feed
-import "github.com/dexon-foundation/dexon/common/hexutil"
+import "github.com/tangerine-network/go-tangerine/common/hexutil"
type binarySerializer interface {
binaryPut(serializedData []byte) error
diff --git a/swarm/storage/feed/binaryserializer_test.go b/swarm/storage/feed/binaryserializer_test.go
index a9bdd7b32..da3961a5a 100644
--- a/swarm/storage/feed/binaryserializer_test.go
+++ b/swarm/storage/feed/binaryserializer_test.go
@@ -21,7 +21,7 @@ import (
"reflect"
"testing"
- "github.com/dexon-foundation/dexon/common/hexutil"
+ "github.com/tangerine-network/go-tangerine/common/hexutil"
)
// KV mocks a key value store
diff --git a/swarm/storage/feed/cacheentry.go b/swarm/storage/feed/cacheentry.go
index 5d7ea11d6..46b03bf6c 100644
--- a/swarm/storage/feed/cacheentry.go
+++ b/swarm/storage/feed/cacheentry.go
@@ -21,7 +21,7 @@ import (
"context"
"time"
- "github.com/dexon-foundation/dexon/swarm/storage"
+ "github.com/tangerine-network/go-tangerine/swarm/storage"
)
const (
diff --git a/swarm/storage/feed/feed.go b/swarm/storage/feed/feed.go
index 93a9958a6..619413a74 100644
--- a/swarm/storage/feed/feed.go
+++ b/swarm/storage/feed/feed.go
@@ -20,9 +20,9 @@ import (
"hash"
"unsafe"
- "github.com/dexon-foundation/dexon/common"
- "github.com/dexon-foundation/dexon/common/hexutil"
- "github.com/dexon-foundation/dexon/swarm/storage"
+ "github.com/tangerine-network/go-tangerine/common"
+ "github.com/tangerine-network/go-tangerine/common/hexutil"
+ "github.com/tangerine-network/go-tangerine/swarm/storage"
)
// Feed represents a particular user's stream of updates on a topic
diff --git a/swarm/storage/feed/handler.go b/swarm/storage/feed/handler.go
index edfcae91d..aba7b52c6 100644
--- a/swarm/storage/feed/handler.go
+++ b/swarm/storage/feed/handler.go
@@ -24,10 +24,10 @@ import (
"fmt"
"sync"
- "github.com/dexon-foundation/dexon/swarm/storage/feed/lookup"
+ "github.com/tangerine-network/go-tangerine/swarm/storage/feed/lookup"
- "github.com/dexon-foundation/dexon/swarm/log"
- "github.com/dexon-foundation/dexon/swarm/storage"
+ "github.com/tangerine-network/go-tangerine/swarm/log"
+ "github.com/tangerine-network/go-tangerine/swarm/storage"
)
type Handler struct {
diff --git a/swarm/storage/feed/handler_test.go b/swarm/storage/feed/handler_test.go
index eb95c82be..b7f0bc8da 100644
--- a/swarm/storage/feed/handler_test.go
+++ b/swarm/storage/feed/handler_test.go
@@ -26,11 +26,11 @@ import (
"testing"
"time"
- "github.com/dexon-foundation/dexon/crypto"
- "github.com/dexon-foundation/dexon/log"
- "github.com/dexon-foundation/dexon/swarm/chunk"
- "github.com/dexon-foundation/dexon/swarm/storage"
- "github.com/dexon-foundation/dexon/swarm/storage/feed/lookup"
+ "github.com/tangerine-network/go-tangerine/crypto"
+ "github.com/tangerine-network/go-tangerine/log"
+ "github.com/tangerine-network/go-tangerine/swarm/chunk"
+ "github.com/tangerine-network/go-tangerine/swarm/storage"
+ "github.com/tangerine-network/go-tangerine/swarm/storage/feed/lookup"
)
var (
diff --git a/swarm/storage/feed/id.go b/swarm/storage/feed/id.go
index 52bfe45a3..2bd885b64 100644
--- a/swarm/storage/feed/id.go
+++ b/swarm/storage/feed/id.go
@@ -21,10 +21,10 @@ import (
"hash"
"strconv"
- "github.com/dexon-foundation/dexon/common"
- "github.com/dexon-foundation/dexon/swarm/storage/feed/lookup"
+ "github.com/tangerine-network/go-tangerine/common"
+ "github.com/tangerine-network/go-tangerine/swarm/storage/feed/lookup"
- "github.com/dexon-foundation/dexon/swarm/storage"
+ "github.com/tangerine-network/go-tangerine/swarm/storage"
)
// ID uniquely identifies an update on the network.
diff --git a/swarm/storage/feed/id_test.go b/swarm/storage/feed/id_test.go
index ee0b4d0a8..85686107d 100644
--- a/swarm/storage/feed/id_test.go
+++ b/swarm/storage/feed/id_test.go
@@ -3,7 +3,7 @@ package feed
import (
"testing"
- "github.com/dexon-foundation/dexon/swarm/storage/feed/lookup"
+ "github.com/tangerine-network/go-tangerine/swarm/storage/feed/lookup"
)
func getTestID() *ID {
diff --git a/swarm/storage/feed/lookup/epoch_test.go b/swarm/storage/feed/lookup/epoch_test.go
index d9e3e7adb..4bfd7262e 100644
--- a/swarm/storage/feed/lookup/epoch_test.go
+++ b/swarm/storage/feed/lookup/epoch_test.go
@@ -3,7 +3,7 @@ package lookup_test
import (
"testing"
- "github.com/dexon-foundation/dexon/swarm/storage/feed/lookup"
+ "github.com/tangerine-network/go-tangerine/swarm/storage/feed/lookup"
)
func TestMarshallers(t *testing.T) {
diff --git a/swarm/storage/feed/lookup/lookup_test.go b/swarm/storage/feed/lookup/lookup_test.go
index fc2096a4a..49075a5c5 100644
--- a/swarm/storage/feed/lookup/lookup_test.go
+++ b/swarm/storage/feed/lookup/lookup_test.go
@@ -21,8 +21,8 @@ import (
"math/rand"
"testing"
- "github.com/dexon-foundation/dexon/swarm/log"
- "github.com/dexon-foundation/dexon/swarm/storage/feed/lookup"
+ "github.com/tangerine-network/go-tangerine/swarm/log"
+ "github.com/tangerine-network/go-tangerine/swarm/storage/feed/lookup"
)
type Data struct {
diff --git a/swarm/storage/feed/query.go b/swarm/storage/feed/query.go
index 785c2b561..abeafd6e3 100644
--- a/swarm/storage/feed/query.go
+++ b/swarm/storage/feed/query.go
@@ -20,8 +20,8 @@ import (
"fmt"
"strconv"
- "github.com/dexon-foundation/dexon/common"
- "github.com/dexon-foundation/dexon/swarm/storage/feed/lookup"
+ "github.com/tangerine-network/go-tangerine/common"
+ "github.com/tangerine-network/go-tangerine/swarm/storage/feed/lookup"
)
// Query is used to specify constraints when performing an update lookup
diff --git a/swarm/storage/feed/request.go b/swarm/storage/feed/request.go
index 9fe3beed0..630718cb3 100644
--- a/swarm/storage/feed/request.go
+++ b/swarm/storage/feed/request.go
@@ -21,10 +21,10 @@ import (
"encoding/json"
"hash"
- "github.com/dexon-foundation/dexon/common"
- "github.com/dexon-foundation/dexon/common/hexutil"
- "github.com/dexon-foundation/dexon/swarm/storage"
- "github.com/dexon-foundation/dexon/swarm/storage/feed/lookup"
+ "github.com/tangerine-network/go-tangerine/common"
+ "github.com/tangerine-network/go-tangerine/common/hexutil"
+ "github.com/tangerine-network/go-tangerine/swarm/storage"
+ "github.com/tangerine-network/go-tangerine/swarm/storage/feed/lookup"
)
// Request represents a request to sign or signed feed update message
diff --git a/swarm/storage/feed/request_test.go b/swarm/storage/feed/request_test.go
index 33626f7ca..70dcd19ef 100644
--- a/swarm/storage/feed/request_test.go
+++ b/swarm/storage/feed/request_test.go
@@ -24,9 +24,9 @@ import (
"reflect"
"testing"
- "github.com/dexon-foundation/dexon/crypto"
- "github.com/dexon-foundation/dexon/swarm/storage"
- "github.com/dexon-foundation/dexon/swarm/storage/feed/lookup"
+ "github.com/tangerine-network/go-tangerine/crypto"
+ "github.com/tangerine-network/go-tangerine/swarm/storage"
+ "github.com/tangerine-network/go-tangerine/swarm/storage/feed/lookup"
)
func areEqualJSON(s1, s2 string) (bool, error) {
diff --git a/swarm/storage/feed/sign.go b/swarm/storage/feed/sign.go
index ded0d90b7..c19a63709 100644
--- a/swarm/storage/feed/sign.go
+++ b/swarm/storage/feed/sign.go
@@ -19,8 +19,8 @@ package feed
import (
"crypto/ecdsa"
- "github.com/dexon-foundation/dexon/common"
- "github.com/dexon-foundation/dexon/crypto"
+ "github.com/tangerine-network/go-tangerine/common"
+ "github.com/tangerine-network/go-tangerine/crypto"
)
const signatureLength = 65
diff --git a/swarm/storage/feed/testutil.go b/swarm/storage/feed/testutil.go
index eb709f8ac..f27ebdcb7 100644
--- a/swarm/storage/feed/testutil.go
+++ b/swarm/storage/feed/testutil.go
@@ -22,8 +22,8 @@ import (
"path/filepath"
"sync"
- "github.com/dexon-foundation/dexon/p2p/enode"
- "github.com/dexon-foundation/dexon/swarm/storage"
+ "github.com/tangerine-network/go-tangerine/p2p/enode"
+ "github.com/tangerine-network/go-tangerine/swarm/storage"
)
const (
diff --git a/swarm/storage/feed/topic.go b/swarm/storage/feed/topic.go
index 005f54201..35b218de7 100644
--- a/swarm/storage/feed/topic.go
+++ b/swarm/storage/feed/topic.go
@@ -21,9 +21,9 @@ import (
"encoding/json"
"fmt"
- "github.com/dexon-foundation/dexon/common/bitutil"
- "github.com/dexon-foundation/dexon/common/hexutil"
- "github.com/dexon-foundation/dexon/swarm/storage"
+ "github.com/tangerine-network/go-tangerine/common/bitutil"
+ "github.com/tangerine-network/go-tangerine/common/hexutil"
+ "github.com/tangerine-network/go-tangerine/swarm/storage"
)
// TopicLength establishes the max length of a topic string
diff --git a/swarm/storage/feed/topic_test.go b/swarm/storage/feed/topic_test.go
index 75724b40e..ef023bdad 100644
--- a/swarm/storage/feed/topic_test.go
+++ b/swarm/storage/feed/topic_test.go
@@ -3,7 +3,7 @@ package feed
import (
"testing"
- "github.com/dexon-foundation/dexon/common/hexutil"
+ "github.com/tangerine-network/go-tangerine/common/hexutil"
)
func TestTopic(t *testing.T) {
diff --git a/swarm/storage/feed/update.go b/swarm/storage/feed/update.go
index 5005b4439..e04eba84c 100644
--- a/swarm/storage/feed/update.go
+++ b/swarm/storage/feed/update.go
@@ -20,7 +20,7 @@ import (
"fmt"
"strconv"
- "github.com/dexon-foundation/dexon/swarm/chunk"
+ "github.com/tangerine-network/go-tangerine/swarm/chunk"
)
// ProtocolVersion defines the current version of the protocol that will be included in each update message
diff --git a/swarm/storage/filestore_test.go b/swarm/storage/filestore_test.go
index f0fe5a8a5..4d5cecf87 100644
--- a/swarm/storage/filestore_test.go
+++ b/swarm/storage/filestore_test.go
@@ -24,7 +24,7 @@ import (
"os"
"testing"
- "github.com/dexon-foundation/dexon/swarm/testutil"
+ "github.com/tangerine-network/go-tangerine/swarm/testutil"
)
const testDataSize = 0x0001000
diff --git a/swarm/storage/hasherstore.go b/swarm/storage/hasherstore.go
index 341756e34..6c7ef1132 100644
--- a/swarm/storage/hasherstore.go
+++ b/swarm/storage/hasherstore.go
@@ -21,8 +21,8 @@ import (
"fmt"
"sync/atomic"
- ch "github.com/dexon-foundation/dexon/swarm/chunk"
- "github.com/dexon-foundation/dexon/swarm/storage/encryption"
+ ch "github.com/tangerine-network/go-tangerine/swarm/chunk"
+ "github.com/tangerine-network/go-tangerine/swarm/storage/encryption"
"golang.org/x/crypto/sha3"
)
diff --git a/swarm/storage/hasherstore_test.go b/swarm/storage/hasherstore_test.go
index 2948024b7..0b9d77653 100644
--- a/swarm/storage/hasherstore_test.go
+++ b/swarm/storage/hasherstore_test.go
@@ -21,9 +21,9 @@ import (
"context"
"testing"
- "github.com/dexon-foundation/dexon/swarm/storage/encryption"
+ "github.com/tangerine-network/go-tangerine/swarm/storage/encryption"
- "github.com/dexon-foundation/dexon/common"
+ "github.com/tangerine-network/go-tangerine/common"
)
func TestHasherStore(t *testing.T) {
diff --git a/swarm/storage/ldbstore.go b/swarm/storage/ldbstore.go
index af39c92fa..130e546db 100644
--- a/swarm/storage/ldbstore.go
+++ b/swarm/storage/ldbstore.go
@@ -34,11 +34,11 @@ import (
"io/ioutil"
"sync"
- "github.com/dexon-foundation/dexon/metrics"
- "github.com/dexon-foundation/dexon/rlp"
- "github.com/dexon-foundation/dexon/swarm/log"
- "github.com/dexon-foundation/dexon/swarm/storage/mock"
"github.com/syndtr/goleveldb/leveldb"
+ "github.com/tangerine-network/go-tangerine/metrics"
+ "github.com/tangerine-network/go-tangerine/rlp"
+ "github.com/tangerine-network/go-tangerine/swarm/log"
+ "github.com/tangerine-network/go-tangerine/swarm/storage/mock"
)
const (
diff --git a/swarm/storage/ldbstore_test.go b/swarm/storage/ldbstore_test.go
index 7d4748a28..aedf5bdd9 100644
--- a/swarm/storage/ldbstore_test.go
+++ b/swarm/storage/ldbstore_test.go
@@ -28,11 +28,11 @@ import (
"testing"
"time"
- "github.com/dexon-foundation/dexon/common"
- ch "github.com/dexon-foundation/dexon/swarm/chunk"
- "github.com/dexon-foundation/dexon/swarm/log"
- "github.com/dexon-foundation/dexon/swarm/storage/mock/mem"
ldberrors "github.com/syndtr/goleveldb/leveldb/errors"
+ "github.com/tangerine-network/go-tangerine/common"
+ ch "github.com/tangerine-network/go-tangerine/swarm/chunk"
+ "github.com/tangerine-network/go-tangerine/swarm/log"
+ "github.com/tangerine-network/go-tangerine/swarm/storage/mock/mem"
)
type testDbStore struct {
diff --git a/swarm/storage/localstore.go b/swarm/storage/localstore.go
index 6020665d6..729654f6e 100644
--- a/swarm/storage/localstore.go
+++ b/swarm/storage/localstore.go
@@ -21,9 +21,9 @@ import (
"path/filepath"
"sync"
- "github.com/dexon-foundation/dexon/metrics"
- "github.com/dexon-foundation/dexon/swarm/log"
- "github.com/dexon-foundation/dexon/swarm/storage/mock"
+ "github.com/tangerine-network/go-tangerine/metrics"
+ "github.com/tangerine-network/go-tangerine/swarm/log"
+ "github.com/tangerine-network/go-tangerine/swarm/storage/mock"
)
type LocalStoreParams struct {
diff --git a/swarm/storage/localstore/gc.go b/swarm/storage/localstore/gc.go
index e53bdabd1..57a7c7cba 100644
--- a/swarm/storage/localstore/gc.go
+++ b/swarm/storage/localstore/gc.go
@@ -92,9 +92,9 @@ package localstore
import (
"time"
- "github.com/dexon-foundation/dexon/log"
- "github.com/dexon-foundation/dexon/swarm/shed"
"github.com/syndtr/goleveldb/leveldb"
+ "github.com/tangerine-network/go-tangerine/log"
+ "github.com/tangerine-network/go-tangerine/swarm/shed"
)
var (
diff --git a/swarm/storage/localstore/gc_test.go b/swarm/storage/localstore/gc_test.go
index fa9f39ece..a12b48c69 100644
--- a/swarm/storage/localstore/gc_test.go
+++ b/swarm/storage/localstore/gc_test.go
@@ -23,7 +23,7 @@ import (
"testing"
"time"
- "github.com/dexon-foundation/dexon/swarm/storage"
+ "github.com/tangerine-network/go-tangerine/swarm/storage"
)
// TestDB_collectGarbageWorker tests garbage collection runs
diff --git a/swarm/storage/localstore/index_test.go b/swarm/storage/localstore/index_test.go
index 326b8d9f2..3a9a72f36 100644
--- a/swarm/storage/localstore/index_test.go
+++ b/swarm/storage/localstore/index_test.go
@@ -21,7 +21,7 @@ import (
"math/rand"
"testing"
- "github.com/dexon-foundation/dexon/swarm/storage"
+ "github.com/tangerine-network/go-tangerine/swarm/storage"
)
// TestDB_pullIndex validates the ordering of keys in pull index.
diff --git a/swarm/storage/localstore/localstore.go b/swarm/storage/localstore/localstore.go
index c828deb12..e849316e0 100644
--- a/swarm/storage/localstore/localstore.go
+++ b/swarm/storage/localstore/localstore.go
@@ -23,10 +23,10 @@ import (
"sync"
"time"
- "github.com/dexon-foundation/dexon/log"
- "github.com/dexon-foundation/dexon/swarm/shed"
- "github.com/dexon-foundation/dexon/swarm/storage"
- "github.com/dexon-foundation/dexon/swarm/storage/mock"
+ "github.com/tangerine-network/go-tangerine/log"
+ "github.com/tangerine-network/go-tangerine/swarm/shed"
+ "github.com/tangerine-network/go-tangerine/swarm/storage"
+ "github.com/tangerine-network/go-tangerine/swarm/storage/mock"
)
var (
diff --git a/swarm/storage/localstore/mode_get.go b/swarm/storage/localstore/mode_get.go
index 16080f4f9..34204e727 100644
--- a/swarm/storage/localstore/mode_get.go
+++ b/swarm/storage/localstore/mode_get.go
@@ -17,10 +17,10 @@
package localstore
import (
- "github.com/dexon-foundation/dexon/log"
- "github.com/dexon-foundation/dexon/swarm/shed"
- "github.com/dexon-foundation/dexon/swarm/storage"
"github.com/syndtr/goleveldb/leveldb"
+ "github.com/tangerine-network/go-tangerine/log"
+ "github.com/tangerine-network/go-tangerine/swarm/shed"
+ "github.com/tangerine-network/go-tangerine/swarm/storage"
)
// ModeGet enumerates different Getter modes.
diff --git a/swarm/storage/localstore/mode_put.go b/swarm/storage/localstore/mode_put.go
index 0052d6c96..7ebcf3d07 100644
--- a/swarm/storage/localstore/mode_put.go
+++ b/swarm/storage/localstore/mode_put.go
@@ -17,9 +17,9 @@
package localstore
import (
- "github.com/dexon-foundation/dexon/swarm/shed"
- "github.com/dexon-foundation/dexon/swarm/storage"
"github.com/syndtr/goleveldb/leveldb"
+ "github.com/tangerine-network/go-tangerine/swarm/shed"
+ "github.com/tangerine-network/go-tangerine/swarm/storage"
)
// ModePut enumerates different Putter modes.
diff --git a/swarm/storage/localstore/mode_set.go b/swarm/storage/localstore/mode_set.go
index 8043af88d..4ce38bfab 100644
--- a/swarm/storage/localstore/mode_set.go
+++ b/swarm/storage/localstore/mode_set.go
@@ -17,8 +17,8 @@
package localstore
import (
- "github.com/dexon-foundation/dexon/swarm/storage"
"github.com/syndtr/goleveldb/leveldb"
+ "github.com/tangerine-network/go-tangerine/swarm/storage"
)
// ModeSet enumerates different Setter modes.
diff --git a/swarm/storage/localstore/subscription_pull.go b/swarm/storage/localstore/subscription_pull.go
index 7c686d31d..00c90552b 100644
--- a/swarm/storage/localstore/subscription_pull.go
+++ b/swarm/storage/localstore/subscription_pull.go
@@ -23,9 +23,9 @@ import (
"fmt"
"sync"
- "github.com/dexon-foundation/dexon/log"
- "github.com/dexon-foundation/dexon/swarm/shed"
- "github.com/dexon-foundation/dexon/swarm/storage"
+ "github.com/tangerine-network/go-tangerine/log"
+ "github.com/tangerine-network/go-tangerine/swarm/shed"
+ "github.com/tangerine-network/go-tangerine/swarm/storage"
)
// SubscribePull returns a channel that provides chunk addresses and stored times from pull syncing index.
diff --git a/swarm/storage/localstore/subscription_pull_test.go b/swarm/storage/localstore/subscription_pull_test.go
index 918ec4513..a1137338d 100644
--- a/swarm/storage/localstore/subscription_pull_test.go
+++ b/swarm/storage/localstore/subscription_pull_test.go
@@ -24,7 +24,7 @@ import (
"testing"
"time"
- "github.com/dexon-foundation/dexon/swarm/storage"
+ "github.com/tangerine-network/go-tangerine/swarm/storage"
)
// TestDB_SubscribePull uploads some chunks before and after
diff --git a/swarm/storage/localstore/subscription_push.go b/swarm/storage/localstore/subscription_push.go
index 4b554c38c..edf623fe5 100644
--- a/swarm/storage/localstore/subscription_push.go
+++ b/swarm/storage/localstore/subscription_push.go
@@ -20,9 +20,9 @@ import (
"context"
"sync"
- "github.com/dexon-foundation/dexon/log"
- "github.com/dexon-foundation/dexon/swarm/shed"
- "github.com/dexon-foundation/dexon/swarm/storage"
+ "github.com/tangerine-network/go-tangerine/log"
+ "github.com/tangerine-network/go-tangerine/swarm/shed"
+ "github.com/tangerine-network/go-tangerine/swarm/storage"
)
// SubscribePush returns a channel that provides storage chunks with ordering from push syncing index.
diff --git a/swarm/storage/localstore/subscription_push_test.go b/swarm/storage/localstore/subscription_push_test.go
index 52f57f52e..02f3a769c 100644
--- a/swarm/storage/localstore/subscription_push_test.go
+++ b/swarm/storage/localstore/subscription_push_test.go
@@ -24,7 +24,7 @@ import (
"testing"
"time"
- "github.com/dexon-foundation/dexon/swarm/storage"
+ "github.com/tangerine-network/go-tangerine/swarm/storage"
)
// TestDB_SubscribePush uploads some chunks before and after
diff --git a/swarm/storage/localstore_test.go b/swarm/storage/localstore_test.go
index 140ea9bf6..7c5acdf9d 100644
--- a/swarm/storage/localstore_test.go
+++ b/swarm/storage/localstore_test.go
@@ -23,7 +23,7 @@ import (
"testing"
"time"
- ch "github.com/dexon-foundation/dexon/swarm/chunk"
+ ch "github.com/tangerine-network/go-tangerine/swarm/chunk"
)
var (
diff --git a/swarm/storage/memstore_test.go b/swarm/storage/memstore_test.go
index 60557c000..061f5bfa7 100644
--- a/swarm/storage/memstore_test.go
+++ b/swarm/storage/memstore_test.go
@@ -20,7 +20,7 @@ import (
"context"
"testing"
- "github.com/dexon-foundation/dexon/swarm/log"
+ "github.com/tangerine-network/go-tangerine/swarm/log"
)
func newTestMemStore() *MemStore {
diff --git a/swarm/storage/mock/db/db.go b/swarm/storage/mock/db/db.go
index 05415fd92..eacf47685 100644
--- a/swarm/storage/mock/db/db.go
+++ b/swarm/storage/mock/db/db.go
@@ -27,8 +27,8 @@ import (
"github.com/syndtr/goleveldb/leveldb"
"github.com/syndtr/goleveldb/leveldb/util"
- "github.com/dexon-foundation/dexon/common"
- "github.com/dexon-foundation/dexon/swarm/storage/mock"
+ "github.com/tangerine-network/go-tangerine/common"
+ "github.com/tangerine-network/go-tangerine/swarm/storage/mock"
)
// GlobalStore contains the LevelDB database that is storing
diff --git a/swarm/storage/mock/db/db_test.go b/swarm/storage/mock/db/db_test.go
index 30caf11a7..252fdbb8e 100644
--- a/swarm/storage/mock/db/db_test.go
+++ b/swarm/storage/mock/db/db_test.go
@@ -23,7 +23,7 @@ import (
"os"
"testing"
- "github.com/dexon-foundation/dexon/swarm/storage/mock/test"
+ "github.com/tangerine-network/go-tangerine/swarm/storage/mock/test"
)
// TestDBStore is running a test.MockStore tests
diff --git a/swarm/storage/mock/mem/mem.go b/swarm/storage/mock/mem/mem.go
index b79d3550f..24bc9bfca 100644
--- a/swarm/storage/mock/mem/mem.go
+++ b/swarm/storage/mock/mem/mem.go
@@ -27,8 +27,8 @@ import (
"io/ioutil"
"sync"
- "github.com/dexon-foundation/dexon/common"
- "github.com/dexon-foundation/dexon/swarm/storage/mock"
+ "github.com/tangerine-network/go-tangerine/common"
+ "github.com/tangerine-network/go-tangerine/swarm/storage/mock"
)
// GlobalStore stores all chunk data and also keys and node addresses relations.
diff --git a/swarm/storage/mock/mem/mem_test.go b/swarm/storage/mock/mem/mem_test.go
index c758bef42..22d0cd74b 100644
--- a/swarm/storage/mock/mem/mem_test.go
+++ b/swarm/storage/mock/mem/mem_test.go
@@ -19,7 +19,7 @@ package mem
import (
"testing"
- "github.com/dexon-foundation/dexon/swarm/storage/mock/test"
+ "github.com/tangerine-network/go-tangerine/swarm/storage/mock/test"
)
// TestGlobalStore is running test for a GlobalStore
diff --git a/swarm/storage/mock/mock.go b/swarm/storage/mock/mock.go
index 59c86f584..63ee439cc 100644
--- a/swarm/storage/mock/mock.go
+++ b/swarm/storage/mock/mock.go
@@ -36,7 +36,7 @@ import (
"errors"
"io"
- "github.com/dexon-foundation/dexon/common"
+ "github.com/tangerine-network/go-tangerine/common"
)
// ErrNotFound indicates that the chunk is not found.
diff --git a/swarm/storage/mock/rpc/rpc.go b/swarm/storage/mock/rpc/rpc.go
index ef8320b9a..2e1bb668d 100644
--- a/swarm/storage/mock/rpc/rpc.go
+++ b/swarm/storage/mock/rpc/rpc.go
@@ -26,10 +26,10 @@ package rpc
import (
"fmt"
- "github.com/dexon-foundation/dexon/common"
- "github.com/dexon-foundation/dexon/rpc"
- "github.com/dexon-foundation/dexon/swarm/log"
- "github.com/dexon-foundation/dexon/swarm/storage/mock"
+ "github.com/tangerine-network/go-tangerine/common"
+ "github.com/tangerine-network/go-tangerine/rpc"
+ "github.com/tangerine-network/go-tangerine/swarm/log"
+ "github.com/tangerine-network/go-tangerine/swarm/storage/mock"
)
// GlobalStore is rpc.Client that connects to a centralized mock store.
diff --git a/swarm/storage/mock/rpc/rpc_test.go b/swarm/storage/mock/rpc/rpc_test.go
index 0f5430ac8..1cc36ab9f 100644
--- a/swarm/storage/mock/rpc/rpc_test.go
+++ b/swarm/storage/mock/rpc/rpc_test.go
@@ -19,9 +19,9 @@ package rpc
import (
"testing"
- "github.com/dexon-foundation/dexon/rpc"
- "github.com/dexon-foundation/dexon/swarm/storage/mock/mem"
- "github.com/dexon-foundation/dexon/swarm/storage/mock/test"
+ "github.com/tangerine-network/go-tangerine/rpc"
+ "github.com/tangerine-network/go-tangerine/swarm/storage/mock/mem"
+ "github.com/tangerine-network/go-tangerine/swarm/storage/mock/test"
)
// TestDBStore is running test for a GlobalStore
diff --git a/swarm/storage/mock/test/test.go b/swarm/storage/mock/test/test.go
index 764ed1528..a09aa68b6 100644
--- a/swarm/storage/mock/test/test.go
+++ b/swarm/storage/mock/test/test.go
@@ -25,9 +25,9 @@ import (
"strconv"
"testing"
- "github.com/dexon-foundation/dexon/common"
- "github.com/dexon-foundation/dexon/swarm/storage"
- "github.com/dexon-foundation/dexon/swarm/storage/mock"
+ "github.com/tangerine-network/go-tangerine/common"
+ "github.com/tangerine-network/go-tangerine/swarm/storage"
+ "github.com/tangerine-network/go-tangerine/swarm/storage/mock"
)
// MockStore creates NodeStore instances from provided GlobalStorer,
diff --git a/swarm/storage/netstore.go b/swarm/storage/netstore.go
index e2734600b..a44f96235 100644
--- a/swarm/storage/netstore.go
+++ b/swarm/storage/netstore.go
@@ -24,9 +24,9 @@ import (
"sync/atomic"
"time"
- "github.com/dexon-foundation/dexon/p2p/enode"
- "github.com/dexon-foundation/dexon/swarm/log"
lru "github.com/hashicorp/golang-lru"
+ "github.com/tangerine-network/go-tangerine/p2p/enode"
+ "github.com/tangerine-network/go-tangerine/swarm/log"
)
type (
diff --git a/swarm/storage/netstore_test.go b/swarm/storage/netstore_test.go
index ef9715626..ed45617b7 100644
--- a/swarm/storage/netstore_test.go
+++ b/swarm/storage/netstore_test.go
@@ -27,9 +27,9 @@ import (
"testing"
"time"
- "github.com/dexon-foundation/dexon/common"
- "github.com/dexon-foundation/dexon/p2p/enode"
- ch "github.com/dexon-foundation/dexon/swarm/chunk"
+ "github.com/tangerine-network/go-tangerine/common"
+ "github.com/tangerine-network/go-tangerine/p2p/enode"
+ ch "github.com/tangerine-network/go-tangerine/swarm/chunk"
)
var sourcePeerID = enode.HexID("99d8594b52298567d2ca3f4c441a5ba0140ee9245e26460d01102a52773c73b9")
diff --git a/swarm/storage/pyramid.go b/swarm/storage/pyramid.go
index 0789e75ae..e958dcdfe 100644
--- a/swarm/storage/pyramid.go
+++ b/swarm/storage/pyramid.go
@@ -25,8 +25,8 @@ import (
"sync"
"time"
- ch "github.com/dexon-foundation/dexon/swarm/chunk"
- "github.com/dexon-foundation/dexon/swarm/log"
+ ch "github.com/tangerine-network/go-tangerine/swarm/chunk"
+ "github.com/tangerine-network/go-tangerine/swarm/log"
)
/*
diff --git a/swarm/storage/types.go b/swarm/storage/types.go
index fa0e4e115..d9b07e73f 100644
--- a/swarm/storage/types.go
+++ b/swarm/storage/types.go
@@ -25,9 +25,9 @@ import (
"fmt"
"io"
- "github.com/dexon-foundation/dexon/common"
- "github.com/dexon-foundation/dexon/swarm/bmt"
- ch "github.com/dexon-foundation/dexon/swarm/chunk"
+ "github.com/tangerine-network/go-tangerine/common"
+ "github.com/tangerine-network/go-tangerine/swarm/bmt"
+ ch "github.com/tangerine-network/go-tangerine/swarm/chunk"
"golang.org/x/crypto/sha3"
)
diff --git a/swarm/storage/localstore/localstore_test.go b/swarm/storage/localstore/localstore_test.go
index 77340875b..33899bc28 100644
--- a/swarm/storage/localstore/localstore_test.go
+++ b/swarm/storage/localstore/localstore_test.go
@@ -28,10 +28,10 @@ import (
"testing"
"time"
- ch "github.com/dexon-foundation/dexon/swarm/chunk"
- "github.com/dexon-foundation/dexon/swarm/shed"
- "github.com/dexon-foundation/dexon/swarm/storage"
"github.com/syndtr/goleveldb/leveldb"
+ ch "github.com/tangerine-network/go-tangerine/swarm/chunk"
+ "github.com/tangerine-network/go-tangerine/swarm/shed"
+ "github.com/tangerine-network/go-tangerine/swarm/storage"
)
// TestDB validates if the chunk can be uploaded and
@@ -130,10 +130,10 @@ func TestDB_updateGCSem(t *testing.T) {
// Measurements on MacBook Pro (Retina, 15-inch, Mid 2014) show
// that New function executes around 1s for database with 1M chunks.
//
// # go test -benchmem -run=none github.com/dexon-foundation/dexon/swarm/storage/localstore -bench BenchmarkNew -v -timeout 20m
// goos: darwin
// goarch: amd64
-// pkg: github.com/dexon-foundation/dexon/swarm/storage/localstore
+// pkg: github.com/tangerine-network/go-tangerine/swarm/storage/localstore
// BenchmarkNew/1000-8 200 11672414 ns/op 9570960 B/op 10008 allocs/op
// BenchmarkNew/10000-8 100 14890609 ns/op 10490118 B/op 7759 allocs/op
// BenchmarkNew/100000-8 20 58334080 ns/op 17763157 B/op 22978 allocs/op
@@ -130,10 +130,10 @@ func TestDB_updateGCSem(t *testing.T) {
// that New function executes around 1s for database with 1M chunks.
//
-// # go test -benchmem -run=none github.com/dexon-foundation/dexon/swarm/storage/localstore -bench BenchmarkNew -v -timeout 20m
+// # go test -benchmem -run=none github.com/tangerine-network/go-tangerine/swarm/storage/localstore -bench BenchmarkNew -v -timeout 20m
// goos: darwin
// goarch: amd64
diff --git a/swarm/storage/localstore/mode_put_test.go b/swarm/storage/localstore/mode_put_test.go
index ca034c03e..f90a66e50 100644
--- a/swarm/storage/localstore/mode_put_test.go
+++ b/swarm/storage/localstore/mode_put_test.go
@@ -23,7 +23,7 @@ import (
"testing"
"time"
- "github.com/dexon-foundation/dexon/swarm/storage"
+ "github.com/tangerine-network/go-tangerine/swarm/storage"
)
// TestModePutRequest validates ModePutRequest index values on the provided DB.
@@ -208,11 +208,11 @@ func TestModePutUpload_parallel(t *testing.T) {
//
// Measurements on MacBook Pro (Retina, 15-inch, Mid 2014)
//
// # go test -benchmem -run=none github.com/dexon-foundation/dexon/swarm/storage/localstore -bench BenchmarkPutUpload -v
//
// goos: darwin
// goarch: amd64
-// pkg: github.com/dexon-foundation/dexon/swarm/storage/localstore
+// pkg: github.com/tangerine-network/go-tangerine/swarm/storage/localstore
// BenchmarkPutUpload/count_100_parallel_1-8 300 5107704 ns/op 2081461 B/op 2374 allocs/op
// BenchmarkPutUpload/count_100_parallel_2-8 300 5411742 ns/op 2081608 B/op 2364 allocs/op
// BenchmarkPutUpload/count_100_parallel_4-8 500 3704964 ns/op 2081696 B/op 2324 allocs/op
@@ -208,11 +208,11 @@ func TestModePutUpload_parallel(t *testing.T) {
// Measurements on MacBook Pro (Retina, 15-inch, Mid 2014)
//
-// # go test -benchmem -run=none github.com/dexon-foundation/dexon/swarm/storage/localstore -bench BenchmarkPutUpload -v
+// # go test -benchmem -run=none github.com/tangerine-network/go-tangerine/swarm/storage/localstore -bench BenchmarkPutUpload -v
//
// goos: darwin
diff --git a/swarm/storage/localstore/retrieval_index_test.go b/swarm/storage/localstore/retrieval_index_test.go
index bccdc6ed9..e4681eb05 100644
--- a/swarm/storage/localstore/retrieval_index_test.go
+++ b/swarm/storage/localstore/retrieval_index_test.go
@@ -20,7 +20,7 @@ import (
"strconv"
"testing"
- "github.com/dexon-foundation/dexon/swarm/storage"
+ "github.com/tangerine-network/go-tangerine/swarm/storage"
)
// BenchmarkRetrievalIndexes uploads a number of chunks in order to measure
@@ -32,10 +32,10 @@ import (
// Measurements on MacBook Pro (Retina, 15-inch, Mid 2014) show
// that two separated indexes perform better.
//
// # go test -benchmem -run=none github.com/dexon-foundation/dexon/swarm/storage/localstore -bench BenchmarkRetrievalIndexes -v
// goos: darwin
// goarch: amd64
-// pkg: github.com/dexon-foundation/dexon/swarm/storage/localstore
+// pkg: github.com/tangerine-network/go-tangerine/swarm/storage/localstore
// BenchmarkRetrievalIndexes/1000-8 20 75556686 ns/op 19033493 B/op 84500 allocs/op
// BenchmarkRetrievalIndexes/10000-8 1 1079084922 ns/op 382792064 B/op 1429644 allocs/op
// BenchmarkRetrievalIndexes/100000-8 1 16891305737 ns/op 2629165304 B/op 12465019 allocs/op
@@ -104,10 +104,10 @@ func benchmarkRetrievalIndexes(b *testing.B, o *Options, count int) {
//
// Measurements on MacBook Pro (Retina, 15-inch, Mid 2014).
//
// go test -benchmem -run=none github.com/dexon-foundation/dexon/swarm/storage/localstore -bench BenchmarkUpload -v
// goos: darwin
// goarch: amd64
-// pkg: github.com/dexon-foundation/dexon/swarm/storage/localstore
+// pkg: github.com/tangerine-network/go-tangerine/swarm/storage/localstore
// BenchmarkUpload/1000-8 20 59437463 ns/op 25205193 B/op 23208 allocs/op
// BenchmarkUpload/10000-8 2 580646362 ns/op 216532932 B/op 248090 allocs/op
// BenchmarkUpload/100000-8 1 22373390892 ns/op 2323055312 B/op 3995903 allocs/op
@@ -32,10 +32,10 @@ import (
// that two separated indexes perform better.
//
-// # go test -benchmem -run=none github.com/dexon-foundation/dexon/swarm/storage/localstore -bench BenchmarkRetrievalIndexes -v
+// # go test -benchmem -run=none github.com/tangerine-network/go-tangerine/swarm/storage/localstore -bench BenchmarkRetrievalIndexes -v
// goos: darwin
// goarch: amd64
@@ -104,10 +104,10 @@ func benchmarkRetrievalIndexes(b *testing.B, o *Options, count int) {
// Measurements on MacBook Pro (Retina, 15-inch, Mid 2014).
//
-// go test -benchmem -run=none github.com/dexon-foundation/dexon/swarm/storage/localstore -bench BenchmarkUpload -v
+// go test -benchmem -run=none github.com/tangerine-network/go-tangerine/swarm/storage/localstore -bench BenchmarkUpload -v
// goos: darwin
// goarch: amd64